==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/servicequotas/kotlin/ServicequotasFunctions.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicequotas.kotlin

import com.pulumi.aws.servicequotas.ServicequotasFunctions.getServicePlain
import com.pulumi.aws.servicequotas.ServicequotasFunctions.getServiceQuotaPlain
import com.pulumi.aws.servicequotas.ServicequotasFunctions.getTemplatesPlain
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServicePlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServicePlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServiceQuotaPlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServiceQuotaPlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesPlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesPlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesTemplate
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceQuotaResult
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceResult
import com.pulumi.aws.servicequotas.kotlin.outputs.GetTemplatesResult
import kotlinx.coroutines.future.await
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceQuotaResult.Companion.toKotlin as getServiceQuotaResultToKotlin
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceResult.Companion.toKotlin as getServiceResultToKotlin
import com.pulumi.aws.servicequotas.kotlin.outputs.GetTemplatesResult.Companion.toKotlin as getTemplatesResultToKotlin

public object ServicequotasFunctions {
    /**
     * Retrieve information about a Service Quotas Service.
     * > **NOTE:** Global quotas apply to all AWS regions, but can only be accessed in `us-east-1` in the Commercial partition or `us-gov-west-1` in the GovCloud partition. In other regions, the AWS API will return the error `The request failed because the specified service does not exist.`
     * ## Example Usage
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetServiceArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var example = ServicequotasFunctions.getService(GetServiceArgs.builder()
     *             .serviceName("Amazon Virtual Private Cloud (Amazon VPC)")
     *             .build());
     *     }
     * }
     * ```
     * @param argument A collection of arguments for invoking getService.
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(argument: GetServicePlainArgs): GetServiceResult =
        getServiceResultToKotlin(getServicePlain(argument.toJava()).await())

    /**
     * @see [getService].
     * @param serviceName Service name to lookup within Service Quotas. Available values can be found with the [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(serviceName: String): GetServiceResult {
        val argument = GetServicePlainArgs(
            serviceName = serviceName,
        )
        return getServiceResultToKotlin(getServicePlain(argument.toJava()).await())
    }

    /**
     * @see [getService].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetServicePlainArgs].
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(argument: suspend GetServicePlainArgsBuilder.() -> Unit):
        GetServiceResult {
        val builder = GetServicePlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getServiceResultToKotlin(getServicePlain(builtArgument.toJava()).await())
    }

    /**
     * Retrieve information about a Service Quota.
     * > **NOTE:** Global quotas apply to all AWS regions, but can only be accessed in `us-east-1` in the Commercial partition or `us-gov-west-1` in the GovCloud partition. In other regions, the AWS API will return the error `The request failed because the specified service does not exist.`
     * ## Example Usage
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetServiceQuotaArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var byQuotaCode = ServicequotasFunctions.getServiceQuota(GetServiceQuotaArgs.builder()
     *             .quotaCode("L-F678F1CE")
     *             .serviceCode("vpc")
     *             .build());
     *         final var byQuotaName = ServicequotasFunctions.getServiceQuota(GetServiceQuotaArgs.builder()
     *             .quotaName("VPCs per Region")
     *             .serviceCode("vpc")
     *             .build());
     *     }
     * }
     * ```
     * @param argument A collection of arguments for invoking getServiceQuota.
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(argument: GetServiceQuotaPlainArgs): GetServiceQuotaResult =
        getServiceQuotaResultToKotlin(getServiceQuotaPlain(argument.toJava()).await())

    /**
     * @see [getServiceQuota].
     * @param quotaCode Quota code within the service. When configured, the data source directly looks up the service quota. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html). One of `quota_code` or `quota_name` must be specified.
     * @param quotaName Quota name within the service. When configured, the data source searches through all service quotas to find the matching quota name. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html). One of `quota_name` or `quota_code` must be specified.
     * @param serviceCode Service code for the quota. Available values can be found with the `aws.servicequotas.getService` data source or [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(
        quotaCode: String? = null,
        quotaName: String? = null,
        serviceCode: String,
    ): GetServiceQuotaResult {
        val argument = GetServiceQuotaPlainArgs(
            quotaCode = quotaCode,
            quotaName = quotaName,
            serviceCode = serviceCode,
        )
        return getServiceQuotaResultToKotlin(getServiceQuotaPlain(argument.toJava()).await())
    }

    /**
     * @see [getServiceQuota].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetServiceQuotaPlainArgs].
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(argument: suspend GetServiceQuotaPlainArgsBuilder.() -> Unit):
        GetServiceQuotaResult {
        val builder = GetServiceQuotaPlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getServiceQuotaResultToKotlin(getServiceQuotaPlain(builtArgument.toJava()).await())
    }

    /**
     * Data source for managing an AWS Service Quotas Templates.
     * ## Example Usage
     * ### Basic Usage
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetTemplatesArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var example = ServicequotasFunctions.getTemplates(GetTemplatesArgs.builder()
     *             .region("us-east-1")
     *             .build());
     *     }
     * }
     * ```
     * @param argument A collection of arguments for invoking getTemplates.
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(argument: GetTemplatesPlainArgs): GetTemplatesResult =
        getTemplatesResultToKotlin(getTemplatesPlain(argument.toJava()).await())

    /**
     * @see [getTemplates].
     * @param region AWS Region to which the quota increases apply.
     * @param templates A list of quota increase templates for specified region. See `templates`.
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(region: String, templates: List<GetTemplatesTemplate>? = null):
        GetTemplatesResult {
        val argument = GetTemplatesPlainArgs(
            region = region,
            templates = templates,
        )
        return getTemplatesResultToKotlin(getTemplatesPlain(argument.toJava()).await())
    }

    /**
     * @see [getTemplates].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetTemplatesPlainArgs].
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(argument: suspend GetTemplatesPlainArgsBuilder.() -> Unit):
        GetTemplatesResult {
        val builder = GetTemplatesPlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getTemplatesResultToKotlin(getTemplatesPlain(builtArgument.toJava()).await())
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/servicequotas/kotlin/ServicequotasFunctions.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicequotas.kotlin

import com.pulumi.aws.servicequotas.ServicequotasFunctions.getServicePlain
import com.pulumi.aws.servicequotas.ServicequotasFunctions.getServiceQuotaPlain
import com.pulumi.aws.servicequotas.ServicequotasFunctions.getTemplatesPlain
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServicePlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServicePlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServiceQuotaPlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetServiceQuotaPlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesPlainArgs
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesPlainArgsBuilder
import com.pulumi.aws.servicequotas.kotlin.inputs.GetTemplatesTemplate
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceQuotaResult
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceResult
import com.pulumi.aws.servicequotas.kotlin.outputs.GetTemplatesResult
import kotlinx.coroutines.future.await
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceQuotaResult.Companion.toKotlin as getServiceQuotaResultToKotlin
import com.pulumi.aws.servicequotas.kotlin.outputs.GetServiceResult.Companion.toKotlin as getServiceResultToKotlin
import com.pulumi.aws.servicequotas.kotlin.outputs.GetTemplatesResult.Companion.toKotlin as getTemplatesResultToKotlin

public object ServicequotasFunctions {
    /**
     * Retrieve information about a Service Quotas Service.
     * > **NOTE:** Global quotas apply to all AWS regions, but can only be accessed in `us-east-1` in the Commercial partition or `us-gov-west-1` in the GovCloud partition. In other regions, the AWS API will return the error `The request failed because the specified service does not exist.`
     * ## Example Usage
     * <!--Start PulumiCodeChooser -->
     * ```typescript
     * import * as pulumi from "@pulumi/pulumi";
     * import * as aws from "@pulumi/aws";
     * const example = aws.servicequotas.getService({
     *     serviceName: "Amazon Virtual Private Cloud (Amazon VPC)",
     * });
     * ```
     * ```python
     * import pulumi
     * import pulumi_aws as aws
     * example = aws.servicequotas.get_service(service_name="Amazon Virtual Private Cloud (Amazon VPC)")
     * ```
     * ```csharp
     * using System.Collections.Generic;
     * using System.Linq;
     * using Pulumi;
     * using Aws = Pulumi.Aws;
     * return await Deployment.RunAsync(() =>
     * {
     *     var example = Aws.ServiceQuotas.GetService.Invoke(new()
     *     {
     *         ServiceName = "Amazon Virtual Private Cloud (Amazon VPC)",
     *     });
     * });
     * ```
     * ```go
     * package main
     * import (
     * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/servicequotas"
     * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
     * )
     * func main() {
     * 	pulumi.Run(func(ctx *pulumi.Context) error {
     * 		_, err := servicequotas.GetService(ctx, &servicequotas.GetServiceArgs{
     * 			ServiceName: "Amazon Virtual Private Cloud (Amazon VPC)",
     * 		}, nil)
     * 		if err != nil {
     * 			return err
     * 		}
     * 		return nil
     * 	})
     * }
     * ```
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetServiceArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var example = ServicequotasFunctions.getService(GetServiceArgs.builder()
     *             .serviceName("Amazon Virtual Private Cloud (Amazon VPC)")
     *             .build());
     *     }
     * }
     * ```
     * ```yaml
     * variables:
     *   example:
     *     fn::invoke:
     *       Function: aws:servicequotas:getService
     *       Arguments:
     *         serviceName: Amazon Virtual Private Cloud (Amazon VPC)
     * ```
     * <!--End PulumiCodeChooser -->
     * @param argument A collection of arguments for invoking getService.
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(argument: GetServicePlainArgs): GetServiceResult =
        getServiceResultToKotlin(getServicePlain(argument.toJava()).await())

    /**
     * @see [getService].
     * @param serviceName Service name to lookup within Service Quotas. Available values can be found with the [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(serviceName: String): GetServiceResult {
        val argument = GetServicePlainArgs(
            serviceName = serviceName,
        )
        return getServiceResultToKotlin(getServicePlain(argument.toJava()).await())
    }

    /**
     * @see [getService].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetServicePlainArgs].
     * @return A collection of values returned by getService.
     */
    public suspend fun getService(argument: suspend GetServicePlainArgsBuilder.() -> Unit): GetServiceResult {
        val builder = GetServicePlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getServiceResultToKotlin(getServicePlain(builtArgument.toJava()).await())
    }

    /**
     * Retrieve information about a Service Quota.
     * > **NOTE:** Global quotas apply to all AWS regions, but can only be accessed in `us-east-1` in the Commercial partition or `us-gov-west-1` in the GovCloud partition. In other regions, the AWS API will return the error `The request failed because the specified service does not exist.`
     * ## Example Usage
     * <!--Start PulumiCodeChooser -->
     * ```typescript
     * import * as pulumi from "@pulumi/pulumi";
     * import * as aws from "@pulumi/aws";
     * const byQuotaCode = aws.servicequotas.getServiceQuota({
     *     quotaCode: "L-F678F1CE",
     *     serviceCode: "vpc",
     * });
     * const byQuotaName = aws.servicequotas.getServiceQuota({
     *     quotaName: "VPCs per Region",
     *     serviceCode: "vpc",
     * });
     * ```
     * ```python
     * import pulumi
     * import pulumi_aws as aws
     * by_quota_code = aws.servicequotas.get_service_quota(quota_code="L-F678F1CE",
     *     service_code="vpc")
     * by_quota_name = aws.servicequotas.get_service_quota(quota_name="VPCs per Region",
     *     service_code="vpc")
     * ```
     * ```csharp
     * using System.Collections.Generic;
     * using System.Linq;
     * using Pulumi;
     * using Aws = Pulumi.Aws;
     * return await Deployment.RunAsync(() =>
     * {
     *     var byQuotaCode = Aws.ServiceQuotas.GetServiceQuota.Invoke(new()
     *     {
     *         QuotaCode = "L-F678F1CE",
     *         ServiceCode = "vpc",
     *     });
     *     var byQuotaName = Aws.ServiceQuotas.GetServiceQuota.Invoke(new()
     *     {
     *         QuotaName = "VPCs per Region",
     *         ServiceCode = "vpc",
     *     });
     * });
     * ```
     * ```go
     * package main
     * import (
     * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/servicequotas"
     * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
     * )
     * func main() {
     * 	pulumi.Run(func(ctx *pulumi.Context) error {
     * 		_, err := servicequotas.LookupServiceQuota(ctx, &servicequotas.LookupServiceQuotaArgs{
     * 			QuotaCode:   pulumi.StringRef("L-F678F1CE"),
     * 			ServiceCode: "vpc",
     * 		}, nil)
     * 		if err != nil {
     * 			return err
     * 		}
     * 		_, err = servicequotas.LookupServiceQuota(ctx, &servicequotas.LookupServiceQuotaArgs{
     * 			QuotaName:   pulumi.StringRef("VPCs per Region"),
     * 			ServiceCode: "vpc",
     * 		}, nil)
     * 		if err != nil {
     * 			return err
     * 		}
     * 		return nil
     * 	})
     * }
     * ```
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetServiceQuotaArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var byQuotaCode = ServicequotasFunctions.getServiceQuota(GetServiceQuotaArgs.builder()
     *             .quotaCode("L-F678F1CE")
     *             .serviceCode("vpc")
     *             .build());
     *         final var byQuotaName = ServicequotasFunctions.getServiceQuota(GetServiceQuotaArgs.builder()
     *             .quotaName("VPCs per Region")
     *             .serviceCode("vpc")
     *             .build());
     *     }
     * }
     * ```
     * ```yaml
     * variables:
     *   byQuotaCode:
     *     fn::invoke:
     *       Function: aws:servicequotas:getServiceQuota
     *       Arguments:
     *         quotaCode: L-F678F1CE
     *         serviceCode: vpc
     *   byQuotaName:
     *     fn::invoke:
     *       Function: aws:servicequotas:getServiceQuota
     *       Arguments:
     *         quotaName: VPCs per Region
     *         serviceCode: vpc
     * ```
     * <!--End PulumiCodeChooser -->
     * @param argument A collection of arguments for invoking getServiceQuota.
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(argument: GetServiceQuotaPlainArgs): GetServiceQuotaResult =
        getServiceQuotaResultToKotlin(getServiceQuotaPlain(argument.toJava()).await())

    /**
     * @see [getServiceQuota].
     * @param quotaCode Quota code within the service. When configured, the data source directly looks up the service quota. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html). One of `quota_code` or `quota_name` must be specified.
     * @param quotaName Quota name within the service. When configured, the data source searches through all service quotas to find the matching quota name. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html). One of `quota_name` or `quota_code` must be specified.
     * @param serviceCode Service code for the quota. Available values can be found with the `aws.servicequotas.getService` data source or [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(
        quotaCode: String? = null,
        quotaName: String? = null,
        serviceCode: String,
    ): GetServiceQuotaResult {
        val argument = GetServiceQuotaPlainArgs(
            quotaCode = quotaCode,
            quotaName = quotaName,
            serviceCode = serviceCode,
        )
        return getServiceQuotaResultToKotlin(getServiceQuotaPlain(argument.toJava()).await())
    }

    /**
     * @see [getServiceQuota].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetServiceQuotaPlainArgs].
     * @return A collection of values returned by getServiceQuota.
     */
    public suspend fun getServiceQuota(argument: suspend GetServiceQuotaPlainArgsBuilder.() -> Unit): GetServiceQuotaResult {
        val builder = GetServiceQuotaPlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getServiceQuotaResultToKotlin(getServiceQuotaPlain(builtArgument.toJava()).await())
    }

    /**
     * Data source for managing an AWS Service Quotas Templates.
     * ## Example Usage
     * ### Basic Usage
     * <!--Start PulumiCodeChooser -->
     * ```typescript
     * import * as pulumi from "@pulumi/pulumi";
     * import * as aws from "@pulumi/aws";
     * const example = aws.servicequotas.getTemplates({
     *     region: "us-east-1",
     * });
     * ```
     * ```python
     * import pulumi
     * import pulumi_aws as aws
     * example = aws.servicequotas.get_templates(region="us-east-1")
     * ```
     * ```csharp
     * using System.Collections.Generic;
     * using System.Linq;
     * using Pulumi;
     * using Aws = Pulumi.Aws;
     * return await Deployment.RunAsync(() =>
     * {
     *     var example = Aws.ServiceQuotas.GetTemplates.Invoke(new()
     *     {
     *         Region = "us-east-1",
     *     });
     * });
     * ```
     * ```go
     * package main
     * import (
     * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/servicequotas"
     * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
     * )
     * func main() {
     * 	pulumi.Run(func(ctx *pulumi.Context) error {
     * 		_, err := servicequotas.GetTemplates(ctx, &servicequotas.GetTemplatesArgs{
     * 			Region: "us-east-1",
     * 		}, nil)
     * 		if err != nil {
     * 			return err
     * 		}
     * 		return nil
     * 	})
     * }
     * ```
     * ```java
     * package generated_program;
     * import com.pulumi.Context;
     * import com.pulumi.Pulumi;
     * import com.pulumi.core.Output;
     * import com.pulumi.aws.servicequotas.ServicequotasFunctions;
     * import com.pulumi.aws.servicequotas.inputs.GetTemplatesArgs;
     * import java.util.List;
     * import java.util.ArrayList;
     * import java.util.Map;
     * import java.io.File;
     * import java.nio.file.Files;
     * import java.nio.file.Paths;
     * public class App {
     *     public static void main(String[] args) {
     *         Pulumi.run(App::stack);
     *     }
     *     public static void stack(Context ctx) {
     *         final var example = ServicequotasFunctions.getTemplates(GetTemplatesArgs.builder()
     *             .region("us-east-1")
     *             .build());
     *     }
     * }
     * ```
     * ```yaml
     * variables:
     *   example:
     *     fn::invoke:
     *       Function: aws:servicequotas:getTemplates
     *       Arguments:
     *         region: us-east-1
     * ```
     * <!--End PulumiCodeChooser -->
     * @param argument A collection of arguments for invoking getTemplates.
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(argument: GetTemplatesPlainArgs): GetTemplatesResult =
        getTemplatesResultToKotlin(getTemplatesPlain(argument.toJava()).await())

    /**
     * @see [getTemplates].
     * @param region AWS Region to which the quota increases apply.
     * @param templates A list of quota increase templates for specified region. See `templates`.
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(region: String, templates: List<GetTemplatesTemplate>? = null): GetTemplatesResult {
        val argument = GetTemplatesPlainArgs(
            region = region,
            templates = templates,
        )
        return getTemplatesResultToKotlin(getTemplatesPlain(argument.toJava()).await())
    }

    /**
     * @see [getTemplates].
     * @param argument Builder for [com&#46;pulumi&#46;aws&#46;servicequotas&#46;kotlin&#46;inputs&#46;GetTemplatesPlainArgs].
     * @return A collection of values returned by getTemplates.
     */
    public suspend fun getTemplates(argument: suspend GetTemplatesPlainArgsBuilder.() -> Unit): GetTemplatesResult {
        val builder = GetTemplatesPlainArgsBuilder()
        builder.argument()
        val builtArgument = builder.build()
        return getTemplatesResultToKotlin(getTemplatesPlain(builtArgument.toJava()).await())
    }
}
